# Getting Started

Get up and running with TorchFX quickly.

```{toctree}
:maxdepth: 2

installation
getting_started
```

## Quick Links

- [Installation](installation.md) - Install TorchFX and its dependencies
- [Getting Started Guide](getting_started.md) - Your first steps with TorchFX
